
/* Chrysalide - Outil d'analyse de fichiers binaires
 * area.c - conservation des localisations de correspondances
 *
 * Copyright (C) 2023 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "area.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : a = première zone de correspondance à comparer.              *
*                b = seconde zone de correspondance à comparer.               *
*                                                                             *
*  Description : Etablit une comparaison entre deux zones de correspondance.  *
*                                                                             *
*  Retour      : Bilan de la comparaison.                                     *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

int compare_match_area_as_dl_item(const dl_list_item *a, const dl_list_item *b)
{
    int result;                             /* Bilan à retourner           */
    match_area_t *area_a;                   /* Première zone à traiter     */
    match_area_t *area_b;                   /* Seconde zone à traiter      */

    area_a = match_area_from_item(a);
    area_b = match_area_from_item(b);

    result = sort_uint64_t(area_a->start, area_b->start);

    if (result == 0)
        result = sort_uint64_t(area_a->end, area_b->end);

    return result;

}
