
/* Chrysalide - Outil d'analyse de fichiers binaires
 * area.h - prototypes pour la conservation des localisations de correspondances
 *
 * Copyright (C) 2023 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _ANALYSIS_SCAN_MATCHES_AREA_H
#define _ANALYSIS_SCAN_MATCHES_AREA_H


#include <assert.h>


#include "../../../arch/vmpa.h"
#include "../../../common/dllist.h"



/* Couverture d'une correspondance */
typedef struct _match_area_t
{
    phys_t start;                           /* Point de départ             */
    phys_t end;                             /* Point d'arrivée (exclus)    */

    DL_LIST_ITEM(link);                     /* Lien vers les maillons      */

    size_t mod_path_index;                  /* Indice de construction      */
    bool has_mod_path;                      /* Validité du champ précédent */

} match_area_t;


#define match_area_from_item(item) \
    (match_area_t *)container_of(item, match_area_t, link)

#define add_tail_match_area(new, head) \
    dl_list_add_tail(new, head, match_area_t, link)

#define del_match_area(item, head) \
    dl_list_del(item, head, match_area_t, link)

#define for_each_match_area(pos, head) \
    dl_list_for_each(pos, head, match_area_t, link)

#define for_each_match_area_safe(pos, head, next) \
    dl_list_for_each_safe(pos, head, next, match_area_t, link)

#define is_last_match_area(item, head) \
    dl_list_is_last(item, head, link)

#define merge_match_areas(head1, head2) \
    dl_list_merge(head1, head2, match_area_t, link)

#define sort_match_areas_no_dup(head, len, cmp, dup)    \
    ({                                                  \
        assert(!dl_list_empty(*(head)));                \
        dl_list_item *hmbr = &(*head)->link;            \
        sort_dl_list_no_dup(&hmbr, len, cmp, dup);      \
        match_area_from_item(hmbr);                     \
    })


/* Etablit une comparaison entre deux zones de correspondance. */
int compare_match_area_as_dl_item(const dl_list_item *, const dl_list_item *);



#endif  /* _ANALYSIS_SCAN_MATCHES_AREA_H */
