
/* Chrysalide - Outil d'analyse de fichiers binaires
 * token.h - prototypes pour les bribes de recherche textuelle
 *
 * Copyright (C) 2023 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _ANALYSIS_SCAN_PATTERNS_TOKEN_H
#define _ANALYSIS_SCAN_PATTERNS_TOKEN_H


#include <glib-object.h>


#include "backend.h"
#include "tokens/node.h"
#include "../matches/bytes.h"



#define G_TYPE_BYTES_TOKEN            g_bytes_token_get_type()
#define G_BYTES_TOKEN(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), G_TYPE_BYTES_TOKEN, GBytesToken))
#define G_IS_BYTES_TOKEN(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), G_TYPE_BYTES_TOKEN))
#define G_BYTES_TOKEN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), G_TYPE_BYTES_TOKEN, GBytesTokenClass))
#define G_IS_BYTES_TOKEN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), G_TYPE_BYTES_TOKEN))
#define G_BYTES_TOKEN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_BYTES_TOKEN, GBytesTokenClass))


/* Encadrement d'une bribe de recherche textuelle (instance) */
typedef struct _GBytesToken GBytesToken;

/* Encadrement d'une bribe de recherche textuelle (classe) */
typedef struct _GBytesTokenClass GBytesTokenClass;


/* Indique le type défini pour une bribe de recherche textuelle. */
GType g_bytes_token_get_type(void);

/* Indique si seuls des mots entiers sont retenus des analyses. */
bool g_bytes_token_target_fullword(const GBytesToken *);

/* Détermine si le gestionnaire est à vocation privée. */
bool g_bytes_token_is_private(const GBytesToken *);

/* Inscrit la définition d'un motif dans un moteur de recherche. */
bool g_bytes_token_enroll(GBytesToken *, GEngineBackend *, size_t);

/* Récupère les identifiants finaux pour un motif recherché. */
bool g_bytes_token_build_id(GBytesToken *, GEngineBackend *);

/* Transforme les correspondances locales en trouvailles. */
void g_bytes_token_check(const GBytesToken *, GScanBytesMatches *);

/* Retrouve l'origine d'une correspondance à partir d'un indice. */
char *g_bytes_token_get_modifier_path(const GBytesToken *, size_t);



#endif  /* _ANALYSIS_SCAN_PATTERNS_TOKEN_H */
